@@ -2,25 +2,58 @@
 #' 
 #' @name income_tax
 #' @param income The individual assessable income.
-#' @param fy.year The financial year in which the income was earned. Tax years 2000-01 to 2016-17 are provided, as well as the tax years 2017-18 to 2019-20, for convenience, under the assumption the 2017 Budget measures will pass. 
-#' In particular, the tax payable is calculated under the assumption that the rate of the Medicare levy will rise to 2.5\% in the 2019-20 tax year.
-#' If fy.year is not given, the current financial year is used by default.
-#' @param age The individual's age.
+#' @param fy.year The financial year in which the income was earned. Tax years 2000-01 to 2018-19 are supported, as well as the tax year 2019-20, for convenience. 
+#' If \code{fy.year} is not given, the current financial year is used by default.
+#' @param age The individual's age. Ignored if \code{.dots.ATO} is provided (and contains
+#' an age variable such as \code{age_range} or \code{Birth_year}).
 #' @param family_status For Medicare and SAPTO purposes.
 #' @param n_dependants An integer for the number of children of the taxpayer (for the purposes of the Medicare levy).
 #' @param return.mode The mode (numeric or integer) of the returned vector.
-#' @param .dots.ATO A data.frame that contains additional information about the individual's circumstances, with columns the same as in the ATO sample files. If \code{.dots.ATO} is a \code{data.table}, I recommend you enclose it with \code{copy()}.
+#' @param .dots.ATO A data.frame that contains additional information about the individual's circumstances, with columns the same as in the ATO sample files.
+#' 
+#' Age variables in \code{.dots.ATO} take precedence over \code{age} and providing both
+#' is a warning.
+#' 
 #' @param allow.forecasts should dates beyond 2019-20 be permitted? Currently, not permitted.
-#' @param .debug (logical, default: \code{FALSE})  If \code{TRUE}, returns a \code{data.table} containing the components. (This argument and its result is liable to change in future versions, possibly without notice.)
+#' @param .debug (logical, default: \code{FALSE})  If \code{TRUE}, returns a \code{data.table} containing the components of income tax calculated. (This argument and its result is liable to change in future versions, possibly without notice.)
 #' @author Tim Cameron, Brendan Coates, Matthew Katzen, Hugh Parsonage, William Young
-#' @details The function 'rolling' is inflexible by design. It is designed to guarantee the correct tax payable in a year.
-#' For years preceding the introduction of SAPTO, the maximum offset is assumed to apply to those above pensionable age. 
 #' @return The total personal income tax payable.
+#' @details The function is inflexible by design.
+#' It is designed to return the correct tax payable in a year, not to model the tax payable 
+#' under different tax settings. (Use \code{\link{model_income_tax}} for that purpose.)
+#' 
+#' 
+#' The function aims to produce the personal income tax payable for the inputs given
+#' in the tax year \code{fy.year}. The function is specified to produce the most accurate 
+#' calculation of personal income tax given the variables in the ATO's 2\% sample files.
+#'  However, many components are absent from these files, while other components could
+#'  not be computed reliably.
+#'  
+#' For the 2018-19 tax year, the function calculates
+#' \describe{
+#' \item{tax on ordinary taxable income}{The tax as specified in Schedule 7 of the 
+#' \emph{Income Tax Rates Act 1986} (Cth).}
+#' \item{Medicare levy}{See \code{\link{medicare_levy}} for details.}
+#' \item{LITO}{See \code{\link{lito}} for details.}
+#' \item{SAPTO}{See \code{\link{sapto}}. For years preceding the introduction of SAPTO, 
+#' the maximum offset is assumed to apply to those above age 65 (since the sample files only provide 5-year 
+#' age groups).}
+#' \item{SBTO}{See \code{\link{small_business_tax_offset}} for details.}
+#' \item{Historical levies}{The flood levy and the temporary budget repair levy.}
+#' }
+#' 
+#' Notably, when used with a 2\% sample file, the function will not be able to correctly account
+#' for different tax rates and offsets among taxpayers with dependants since the sample files
+#' (as of 2015-16) do not have this information.
+#' 
+#' 
 #' @examples 
 #' 
 #' income_tax(50e3, "2013-14")
 #' 
 #' ## Calculate tax for each lodger in the 2013-14 sample file.
+#' ## Essentially, this is the only use-case for `income_tax`
+#' 
 #' if (requireNamespace("taxstats", quietly = TRUE)) {
 #'   library(data.table)
 #'   library(taxstats)
@@ -40,7 +73,7 @@ income_tax <- function(income,
                        return.mode = c("numeric", "integer"),
                        allow.forecasts = FALSE,
                        .debug = FALSE) {
-  if (is.null(fy.year)){
+  if (is.null(fy.year)) {
     fy.year <- date2fy(Sys.Date())
     warning("fy.year is missing, using current financial year")
   }
@@ -138,6 +171,10 @@ rolling_income_tax <- function(income,
       sapto.eligible <- age >= 65
     }
   } else {
+    if (!is.null(age)) {
+      warning("`age` is not NULL but `.dots.ATO` is supplied with an age variable, ",
+              "so age will be ignored.")
+    }
     if ("age_range" %chin% .dots.ATO.noms) {
       if ("Birth_year" %chin% .dots.ATO.noms) {
         sapto.eligible <- coalesce(between(.subset2(.dots.ATO, "age_range"), 0L, 1L), 
@@ -197,7 +234,10 @@ rolling_income_tax <- function(income,
   }
   
   if (is.null(.dots.ATO) || "Spouse_adjusted_taxable_inc" %notin% names(.dots.ATO)){
-    the_spouse_income <- 0L
+    # integer(max.length) rather than just 0L because we subset later
+    #   the_spouse_income[wse]
+    # to help solving #158
+    the_spouse_income <- integer(max.length)
   } else {
     the_spouse_income <- .subset2(.dots.ATO, "Spouse_adjusted_taxable_inc")
     the_spouse_income[is.na(the_spouse_income)] <- if (is.double(the_spouse_income)) 0 else 0L
@@ -222,24 +262,32 @@ rolling_income_tax <- function(income,
   
   if (any(sapto.eligible)) {
     sapto. <- double(max.length)
-    if (!is.null(.dots.ATO) && all(c("Rptbl_Empr_spr_cont_amt",
-                                     "Net_fincl_invstmt_lss_amt",
-                                     "Net_rent_amt", 
-                                     "Rep_frng_ben_amt") %chin% names(.dots.ATO))) {
-      sapto.[sapto.eligible] <-
-        sapto(rebate_income = rebate_income(Taxable_Income = income[sapto.eligible],
-                                            Rptbl_Empr_spr_cont_amt = .dots.ATO[sapto.eligible][["Rptbl_Empr_spr_cont_amt"]],
-                                            Net_fincl_invstmt_lss_amt = .dots.ATO[sapto.eligible][["Net_fincl_invstmt_lss_amt"]],
-                                            Net_rent_amt = .dots.ATO[sapto.eligible][["Net_rent_amt"]],
-                                            Rep_frng_ben_amt = .dots.ATO[sapto.eligible][["Rep_frng_ben_amt"]]), 
-          fy.year = if (length(fy.year) > 1) fy.year[sapto.eligible] else fy.year,
-          Spouse_income = the_spouse_income[sapto.eligible],
-          family_status = {
-            FS_sapto <- rep_len("single", max.length)
-            FS_sapto[the_spouse_income > 0] <- "married"
-            FS_sapto[sapto.eligible]
-          },
-          sapto.eligible = TRUE)
+    if (!is.null(.dots.ATO)) {
+      wse <- which(sapto.eligible)
+      dase <- function(v) {
+        if (v %in% names(.dots.ATO)) {
+          .subset2(.dots.ATO, v)[wse]
+        } else {
+          # If the name is absent, choose zero, 
+          # length is irrelevant since we just add it inside rebate income
+         0
+        }
+      }
+      
+      sapto.[wse] <-
+        sapto(rebate_income = rebate_income(Taxable_Income = income[wse],
+                                            Rptbl_Empr_spr_cont_amt = dase("Rptbl_Empr_spr_cont_amt"),
+                                            Net_fincl_invstmt_lss_amt = dase("Net_fincl_invstmt_lss_amt"),
+                                            Net_rent_amt = dase("Net_rent_amt"),
+                                            Rep_frng_ben_amt = dase("Rep_frng_ben_amt")), 
+              fy.year = if (length(fy.year) > 1) fy.year[wse] else fy.year,
+              Spouse_income = the_spouse_income[wse],
+              family_status = {
+                FS_sapto <- rep_len("single", max.length)
+                FS_sapto[the_spouse_income > 0] <- "married"
+                FS_sapto[wse]
+              },
+              sapto.eligible = TRUE)
     } else {
       sapto.[sapto.eligible] <- 
         sapto(rebate_income = rebate_income(Taxable_Income = income[sapto.eligible]), 
@@ -283,6 +331,34 @@ rolling_income_tax <- function(income,
                                 fy_year = fy.year)
   }
   
+  if (.debug && is.data.table(.dots.ATO)) {
+    new_tax <-
+      pmaxIPnum0(S4.10_basic_income_tax_liability - sbto.) +
+      medicare_levy. +
+      temp_budget_repair_levy. +
+      flood_levy.
+    
+    result <- 
+      as.data.table(.dots.ATO) %>%
+      .[, "base_tax" := base_tax.] %>%
+      .[, "lito" := lito.] %>%
+      .[wse, "rebate_income" := rebate_income(Taxable_Income = income[wse],
+                                              Rptbl_Empr_spr_cont_amt = dase("Rptbl_Empr_spr_cont_amt"),
+                                              Net_fincl_invstmt_lss_amt = dase("Net_fincl_invstmt_lss_amt"),
+                                              Net_rent_amt = dase("Net_rent_amt"),
+                                              Rep_frng_ben_amt = dase("Rep_frng_ben_amt"))] %>%
+      .[, "sapto" := sapto.] %>%
+      .[, "medicare_levy" := medicare_levy.] %>%
+      .[, "SBTO" := sbto.] %>%
+      .[, "new_tax" := new_tax]
+    
+    # if (fy.year == "2011-12") {
+    #   result[, "flood_levy" := flood_levy.]
+    # }
+    
+    return(result[])
+  }
+  
   # SBTO is non-refundable (Para 1.6 of explanatory memo)
   pmaxIPnum0(S4.10_basic_income_tax_liability - sbto.) +
     medicare_levy. +
@@ -295,7 +371,12 @@ rolling_income_tax <- function(income,
 
 
 
-income_tax_cpp <- function(income, fy.year, .dots.ATO = NULL, sapto.eligible = NULL, n_dependants = 0L, .debug = FALSE) {
+income_tax_cpp <- function(income,
+                           fy.year,
+                           .dots.ATO = NULL, 
+                           sapto.eligible = NULL,
+                           n_dependants = 0L, 
+                           .debug = FALSE) {
   # Assume everyone of pension age is eligible for sapto.
   .dots.ATO.noms <- names(.dots.ATO)
   
@@ -436,7 +517,7 @@ income_tax_cpp <- function(income, fy.year, .dots.ATO = NULL, sapto.eligible = N
                   "Rep_frng_ben_amt") %chin% .dots.ATO.noms))) {
       sapto. <- double(max.length)
       .dAse <- function(v) {
-        .dots.ATO[which_sapto, eval(parse(text = v))]
+        .subset2(.dots.ATO, v)[which_sapto]
       }
       
       sapto.[which_sapto] <-
